<script setup>
import { ref, nextTick } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';

const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const initFormData = {}
let formData = ref(initFormData);

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;
    post(isSave.value ? '/api/user/save' : '/api/user/update', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

const DeptQueryList = ref(null);
DeptQuery();
function DeptQuery() {
    postForm('/api/dept/query', {}).then(resp => {
        let result = resp.data;
        DeptQueryList.value = result.data;
    })
}
const UserQueryList = ref(null);
UserQuery();
function UserQuery() {
    postForm('/api/user/query', {}).then(resp => {
        let result = resp.data;
        UserQueryList.value = result.data;
    })
}


defineExpose({
    open,
    formData,
    initFormData,
    isSave,
})

</script>

<script>
export default {
    name: '用户管理-edit'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 600px;">
            <a-form :model="formData" name="formTable" :label-col="{ span: 8 }" :wrapper-col="{ span: 16 }"
                style="display: flex;justify-content: space-between;flex-wrap: wrap;" autocomplete="off"
                @finish="onFinish" @finishFailed="onFinishFailed">
                <a-form-item :label="formatMessage('db.sys_user.username', '账号')" name="username" style="width: 250px;"
                    :rules="[{ required: true }]">
                    <a-input v-model:value="formData.username" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.nickname', '昵称')" name="nickname"
                    style="width: 250px;">
                    <a-input v-model:value="formData.nickname" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.avatar', '头像')" name="avatar" style="width: 250px;">
                    <a-input v-model:value="formData.avatar" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.code', '工号')" name="code" style="width: 250px;">
                    <a-input v-model:value="formData.code" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.sex', '性别')" name="sex" style="width: 250px;">
                    <a-select v-model:value="formData.sex" :options="[
                        { label: '未知', value: 0 },
                        { label: '男', value: 1 },
                        { label: '女', value: 2 },
                    ]">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.phone', '手机号')" name="phone" style="width: 250px;">
                    <a-input v-model:value="formData.phone" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.email', '邮箱')" name="email" style="width: 250px;">
                    <a-input v-model:value="formData.email" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.email_verified', '邮箱验证')" name="emailVerified"
                    style="width: 250px;">
                    <a-select v-model:value="formData.emailVerified" :options="[
                        { label: '否', value: 0 },
                        { label: '是', value: 1 },
                    ]">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.dept_id', '所属部门')" name="deptId" style="width: 250px;">
                    <a-select v-model:value="formData.deptId" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="DeptQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.real_name', '真实姓名')" name="realName"
                    style="width: 250px;">
                    <a-input v-model:value="formData.realName" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.id_card', '身份证号')" name="idCard" style="width: 250px;">
                    <a-input v-model:value="formData.idCard" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.birthday', '出生日期')" name="birthday"
                    style="width: 250px;">
                    <a-input v-model:value="formData.birthday" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.introduction', '个人简介')" name="introduction"
                    style="width: 250px;">
                    <a-input v-model:value="formData.introduction" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.status', '状态')" name="status" style="width: 250px;">
                    <a-select v-model:value="formData.status" :options="[
                        { label: '正常', value: 1 },
                        { label: '禁用', value: 0 },
                    ]">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.create_time', '添加时间')" name="createTime"
                    style="width: 250px;">
                    <a-date-picker v-model:value="formData.createTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.create_by', '添加人员')" name="createBy"
                    style="width: 250px;">
                    <a-select v-model:value="formData.createBy" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="UserQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.update_time', '修改时间')" name="updateTime"
                    style="width: 250px;">
                    <a-date-picker v-model:value="formData.updateTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.update_by', '修改人员')" name="updateBy"
                    style="width: 250px;">
                    <a-select v-model:value="formData.updateBy" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="UserQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.sys_user.memo', '备注')" name="memo" style="width: 250px;">
                    <a-input v-model:value="formData.memo" />
                </a-form-item>

                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>
        </a-modal>
    </div>
</template>

<style></style>
